@@ -6,10 +6,10 @@ void ICMP::logConnection(Record const &record) const
                 " thru " << record.endTime() << 
                 ShowSeconds::utcMarker() << ": icmp " <<
                 record.sourceIPstr() << 
-                " (via: " << record.viaIPstr()  << ") "
-                "to " << record.destIPstr() << "; "
-                "sent: " << record.sentBytes() << ", "
-                "received: " << record.receivedBytes() << 
+                "       (via: " << record.viaIPstr()  << ")       "
+                "to " << record.destIPstr() << ";       "
+                "sent: "     << setw(10) << record.sentBytes() << ", "
+                "received: " << setw(10) << record.receivedBytes() << 
                 logType().first << endl;
 
     logCSV(record);
