@@ -9,12 +9,14 @@ void IPbase::logConnection(Record const &record) const
             " thru " << record.endTime() << 
             ShowSeconds::utcMarker() << ": " << 
             record.protocolStr() << ' ' <<
-            record.sourceIPstr() << ',' << record.sourcePort() << 
+            record.sourceIPstr() << ',' << 
+                                left << setw(5) << record.sourcePort() << 
             " (via: " << record.viaIPstr()  << ',' << 
-                                                    record.viaPort() << ") "
-            "to " << record.destIPstr() << ',' << record.destPort() << "; "
-            "sent: " << record.sentBytes() << ", "
-            "received: " << record.receivedBytes() << 
+                                setw(5) << record.viaPort() << ") "
+            "to " << record.destIPstr() << ',' <<  
+                                showLeft(record.destPort()) << right << 
+            "sent: "     << setw(10) << record.sentBytes() << ", "
+            "received: " << setw(10) << record.receivedBytes() << 
             s_logTypeText[s_logType].first << endl;
 
         logCSV(record);
