@@ -10,6 +10,7 @@ namespace   // the anonymous namespace can be used here
         Arg::LongOption("conntrack-command", Arg::Required),
         Arg::LongOption("conntrack-device", Arg::Required),
         Arg::LongOption("conntrack-restart", Arg::Required),
+        Arg::LongOption("debug", Arg::None),
         Arg::LongOption("help", 'h'),
         Arg::LongOption("log", Arg::Required),
         Arg::LongOption("log-data", Arg::Required),
@@ -35,6 +36,13 @@ namespace   // the anonymous namespace can be used here
 int main(int argc, char **argv)
 try
 {
+    auto argVector = systemdFix(argc, argv);
+    if (argVector.size())
+    {
+        argc = argVector.size();
+        argv = const_cast<char **>(String::argv(argVector));
+    }
+
     ArgConfig &arg = ArgConfig::initialize("c:hp:P:st:T:vV", 
                         longOptions, longEnd, argc, argv);
     
