@@ -1,5 +1,10 @@
 #include "natfork.ih"
 
+//f: NatFork::childProcess()
+    //c: DevicesProducer::DevicesProducer(std::ostream&, Storage&)
+    //c: TcpdumpProducer::TcpdumpProducer(std::ostream&, Storage&)
+    //c: ConntrackProducer::ConntrackProducer(std::ostream&, Storage&)
+
 void NatFork::childProcess()
 {
     ShowSeconds::setFormat();
@@ -16,16 +21,24 @@ void NatFork::childProcess()
                          };
     ConnectionsConsumer connections{ d_stdMsg, storage };
 
+    d_stdMsg << "processing: " << d_options.protocolNames() << endl;
+
     if (d_options.daemon())
         prepareDaemon();
 
+    RotatingStreambuf::startThread();
+
     thread producerThread{ Producer::process, producer.get(), ref(storage) };
 
     connections.run();
 
     producerThread.join();
 
+    d_stdMsg << "NatFork::childProcess notifying RotatingStreambuf" << endl;    
+
     RotatingStreambuf::notify();             // ends the log-rotating threads.
+
+    d_stdMsg << "NatFork::childProcess ends" << endl;    
 }
 
 
