@@ -26,6 +26,7 @@ progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
 "      --conntrack-restart max - max number of times `conntrack' is\n"
 "                           restarted if prematurely ended\n"
 "                           (default 10 restarts)\n"
+"      --debug            - log debug messages (unless --log off)\n"
 "      --help (-h)        - provide this help\n"
 "      --log type         - log information abount connections.\n"
 "                           Specify `type' as:\n"
@@ -47,6 +48,9 @@ progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
                                                         progname << "\n"
 "                           command. Use colon separated combinations of\n"
 "                           tcp (default), udp and icmp, or use `all'\n"
+"      -S                 - systemd fix: specify this as first argument "
+                                                                    "when\n"
+"                           starting " << progname << " from natlog.service\n"
 "      --stdout (-s)      - write syslog-equivalent messages to the std "
                                                                     "output\n"
 "                            (implied by --verbose; only with --no-daemon)\n"
@@ -68,10 +72,9 @@ progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
 "                               local: local date and time\n"
 "      --ttl (-T) secs    - time-to-live for received connections. Format:\n"
 "                           `<secs>u' (UDP/ICMP ttl) and/or `<secs>t'\n"
-"                           (TCP ttl). Default: u" << Options::TTL << 
-                                               't' << Options::TTL_TCP << "\n"
-"                           info about connections is logged if they are "
-                                                                    "not\n"
+"                           (TCP ttl). Default: " << Options::TTL << 'u' << 
+                                                    Options::TTL_TCP << "t\n"
+"                           info about a connection is logged if it is not\n"
 "                           active for `secs' seconds\n"
 "      --verbose (-V)     - write additional information:\n"
 "                               with --no-daemon: to stdout;\n"
@@ -101,5 +104,4 @@ progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
                                                             "in-device\n"
 "                   `outAddr outMask': address and netmask of the "
                                                             "out-device\n";
-
 }
